@@ -2,6 +2,21 @@
 linRegClass <- R6::R6Class(
     "linRegClass",
     inherit = linRegBase,
+    #### Active bindings ----
+    active = list(
+        residuals = function() {
+            data <- private$.cleanData()
+            formulas <- private$.formulas()
+
+            res <- list()
+            for (i in seq_along(formulas)) {
+                model <- lm(formulas[[i]], data=data)
+                res[[i]] <- model$residuals
+            }
+
+            return(res)
+        }
+    ),
     private = list(
         #### Member variables ----
         terms = NULL,
@@ -865,6 +880,8 @@ linRegClass <- R6::R6Class(
                             weights <- 'cells'
 
                         suppressMessages({
+                            emmeans::emm_options(sep = ",", parens = "a^")
+
                             mm <- try(
                                 emmeans::emmeans(model, formula, cov.reduce=FUN, options=list(level=self$options$ciWidthEmm / 100), weights = weights, data=data),
                                 silent = TRUE
